==> yy-formulas-1.0.7.tgz: package/es/Formulas.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import TabsComponents from './components/TabsComponents';

var Formulas =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Formulas, _React$Component);

  function Formulas(props) {
    var _this;

    _classCallCheck(this, Formulas);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Formulas).call(this, props));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.onClick = _this.onClick.bind(_assertThisInitialized(_this));
    _this.onCancel = _this.onCancel.bind(_assertThisInitialized(_this));
    _this.onSubmit = _this.onSubmit.bind(_assertThisInitialized(_this));
    _this.onValidate = _this.onValidate.bind(_assertThisInitialized(_this));
    _this.onValueSelected = _this.onValueSelected.bind(_assertThisInitialized(_this));
    _this.onClear = _this.onClear.bind(_assertThisInitialized(_this));
    _this.onInsertValue = _this.onInsertValue.bind(_assertThisInitialized(_this));
    _this.onDesc = _this.onDesc.bind(_assertThisInitialized(_this));
    _this.state = {
      value: _this.props.textareaValue,
      tabs: _this.props.tabs,
      tabsJSON: JSON.stringify(_this.props.tabs),
      activeKey: _this.props.activeKey,
      DocumentTreeData: _this.props.DocumentTreeData,
      DocumentTreeDataJSON: JSON.stringify(_this.props.DocumentTreeData),
      textDescription: '' // this.yyFormulasTextareaRef = React.createRef()

    };
    return _this;
  }

  _createClass(Formulas, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (nextProps.textareaValue != this.state.value) {
        this.setState({
          value: nextProps.textareaValue
        });
      }

      if (JSON.stringify(nextProps.tabs) != this.state.tabsJSON) {
        this.setState({
          tabs: nextProps.tabs,
          tabsJSON: JSON.stringify(nextProps.tabs)
        });
      }

      if (nextProps.activeKey != this.state.activeKey) {
        var activeKey = nextProps.activeKey;
        this.setState({
          activeKey: activeKey
        });
      }

      if (JSON.stringify(nextProps.DocumentTreeData) != this.state.DocumentTreeData) {
        this.setState({
          DocumentTreeData: nextProps.DocumentTreeData,
          DocumentTreeDataJSON: JSON.stringify(nextProps.DocumentTreeData)
        });
      }
    }
  }, {
    key: "onChange",
    value: function onChange(event) {
      var _this2 = this;

      var value = event.target.value;
      this.setState({
        value: value
      }, function () {
        _this2.props.onChange(value);
      });
    }
  }, {
    key: "onClick",
    value: function onClick(item) {
      if (this[item.event]) {
        this[item.event]();
      } else if (this.props[item.event]) {
        this.props[item.event](this.state.value);
      }
    }
  }, {
    key: "onCancel",
    value: function onCancel() {
      this.props.onCancel(this.state.value);
    }
  }, {
    key: "onSubmit",
    value: function onSubmit() {
      this.props.onSubmit(this.state.value);
    }
  }, {
    key: "onValidate",
    value: function onValidate() {
      this.props.onValidate(this.state.value);
    }
  }, {
    key: "onValueSelected",
    value: function onValueSelected() {
      // this.yyFormulasTextareaRef.current.select()
      this.yyFormulasTextareaRef.select();
    }
  }, {
    key: "onClear",
    value: function onClear() {
      var _this3 = this;

      this.setState({
        value: ''
      }, function () {
        _this3.props.onChange('');
      });
    }
  }, {
    key: "onInsertValue",
    value: function onInsertValue(val) {
      var _this4 = this;

      // console.log([this,this.yyFormulasTextareaRef])
      var yyFormulasTextareaRef = this.yyFormulasTextareaRef; // this.yyFormulasTextareaRef.current

      if (document.selection) {
        var sel = document.selection.createRange();
        sel.text = val;
      } else if (typeof yyFormulasTextareaRef.selectionStart === 'number' && typeof yyFormulasTextareaRef.selectionEnd === 'number') {
        var startPos = yyFormulasTextareaRef.selectionStart;
        var endPos = yyFormulasTextareaRef.selectionEnd;
        var tmpStr = this.state.value;
        var value = tmpStr.substring(0, startPos) + val + tmpStr.substring(endPos, tmpStr.length);
        this.setState({
          value: value
        }, function () {
          yyFormulasTextareaRef.selectionStart = _this4.state.value.length;
          yyFormulasTextareaRef.selectionEnd = _this4.state.value.length;
        });
      } else {
        this.setState({
          value: val
        }, function () {
          yyFormulasTextareaRef.selectionStart = _this4.state.value.length;
          yyFormulasTextareaRef.selectionEnd = _this4.state.value.length;
        });
      }
    }
  }, {
    key: "onDesc",
    value: function onDesc(key) {
      var textDescription = key ? key.toUpperCase() + '：' + this.props.Description['' + key.toUpperCase()] : '';
      this.setState({
        textDescription: textDescription
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this5 = this;

      var _this$props = this.props,
          prefixCls = _this$props.prefixCls,
          textareaPlaceholder = _this$props.textareaPlaceholder,
          buttonList = _this$props.buttonList,
          tabsPrefixCls = _this$props.tabsPrefixCls,
          ReferDataUrl = _this$props.ReferDataUrl,
          fixedData = _this$props.fixedData,
          SubjectData = _this$props.SubjectData,
          FunctionData = _this$props.FunctionData,
          Description = _this$props.Description;
      return React.createElement("div", {
        className: prefixCls
      }, React.createElement("div", {
        className: "row"
      }, React.createElement("div", {
        className: prefixCls + '-textarea-warp col-xs-10 col-md-10 col-sm-10'
      }, React.createElement("textarea", {
        className: prefixCls + '-textarea form-control',
        onChange: this.onChange,
        placeholder: textareaPlaceholder,
        ref: function ref(_ref) {
          return _this5.yyFormulasTextareaRef = _ref;
        },
        value: this.state.value
      })), React.createElement("div", {
        className: prefixCls + '-button-warp col-xs-2 col-md-2 col-sm-2'
      }, buttonList.map(function (item, index) {
        return React.createElement("button", {
          key: index,
          className: prefixCls + '-button ' + item.className,
          onClick: _this5.onClick.bind(_this5, item)
        }, item.name);
      }))), React.createElement("div", {
        className: "row"
      }, React.createElement(TabsComponents, {
        prefixCls: tabsPrefixCls,
        tabs: this.state.tabs,
        activeKey: this.state.activeKey,
        DocumentTreeData: this.state.DocumentTreeData,
        onInsertValue: this.onInsertValue,
        ReferDataUrl: ReferDataUrl,
        fixedData: fixedData,
        SubjectData: SubjectData,
        onDesc: this.onDesc,
        FunctionData: FunctionData,
        Description: Description,
        onClear: this.onClear
      })), React.createElement("p", {
        className: "formulas-desc"
      }, this.state.textDescription));
    }
  }]);

  return Formulas;
}(React.Component);

var noop = function noop() {
  return null;
};

Formulas.propTypes = {
  prefixCls: PropTypes.string,
  textareaPlaceholder: PropTypes.string,
  textareaValue: PropTypes.string,
  buttonList: PropTypes.array,
  onCancel: PropTypes.func,
  onChange: PropTypes.func,
  onSubmit: PropTypes.func,
  onValidate: PropTypes.func,
  tabsPrefixCls: PropTypes.string,
  tabs: PropTypes.array,
  activeKey: PropTypes.string,
  //PropTypes.oneOfType([PropTypes.string,PropTypes.number]),
  DocumentTreeData: PropTypes.array,
  ReferDataUrl: PropTypes.string,
  fixedData: PropTypes.object,
  Description: PropTypes.object,
  FunctionData: PropTypes.array
};
Formulas.defaultProps = {
  prefixCls: 'yy-formulas',
  textareaPlaceholder: '请输入...',
  textareaValue: '',
  buttonList: [{
    name: '确定',
    className: 'btn btn-default',
    event: 'onSubmit'
  }, {
    name: '取消',
    className: 'btn btn-default',
    event: 'onCancel'
  }, {
    name: '验证',
    className: 'btn btn-default',
    event: 'onValidate'
  }, {
    name: '全选',
    className: 'btn btn-default',
    event: 'onValueSelected'
  }, {
    name: '清空',
    className: 'btn btn-default',
    event: 'onClear'
  }],
  onCancel: noop,
  onChange: noop,
  onSubmit: noop,
  onValidate: noop,
  tabsPrefixCls: 'rc-tabs',
  tabs: [{
    id: 0,
    name: '单据字段',
    type: 'sys',
    component: 'Document',
    disabled: false,
    placeholder: '请输入...',
    notFoundContent: '暂无数据',
    positionName: '定位:',
    okName: '确定'
  }, {
    id: 1,
    name: '固定值',
    type: 'sys',
    component: 'Fixed',
    disabled: false,
    placeholder: '请输入...',
    notFoundContent: '暂无数据',
    showName1: '档案',
    showName2: '档案值'
  }, {
    id: 2,
    name: '科目转换',
    type: 'sys',
    component: 'Subject',
    disabled: false,
    placeholder: '请输入...',
    notFoundContent: '暂无数据',
    positionName: '定位：',
    okName: '确定'
  }, {
    id: 3,
    name: '辅助核算类型',
    type: 'sys',
    component: 'Auxiliary',
    disabled: false,
    placeholder: '请输入...',
    notFoundContent: '暂无数据',
    showName: '辅助核算类型',
    onChange: noop
  }, {
    id: 4,
    name: '辅助核算值',
    type: 'sys',
    component: 'Auxiliary',
    disabled: false,
    placeholder: '请输入...',
    notFoundContent: '暂无数据',
    showName: '辅助核算值'
  }, {
    id: 5,
    name: '函数',
    type: 'sys',
    component: 'Function',
    disabled: false,
    notFoundContent: '暂无数据',
    positionName: '定位:',
    okName: '确定'
  }],
  activeKey: '0',
  DocumentTreeData: [],
  ReferDataUrl: '',
  fixedData: {},
  Description: {},
  FunctionData: []
};
polyfill(Formulas);
export default Formulas;

==> yy-formulas-1.0.14.tgz: package/es/Formulas.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import TabsComponents from './components/TabsComponents';

var Formulas =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Formulas, _React$Component);

  function Formulas(props) {
    var _this;

    _classCallCheck(this, Formulas);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Formulas).call(this, props));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.onClick = _this.onClick.bind(_assertThisInitialized(_this));
    _this.onCancel = _this.onCancel.bind(_assertThisInitialized(_this));
    _this.onSubmit = _this.onSubmit.bind(_assertThisInitialized(_this));
    _this.onValidate = _this.onValidate.bind(_assertThisInitialized(_this));
    _this.onValueSelected = _this.onValueSelected.bind(_assertThisInitialized(_this));
    _this.onClear = _this.onClear.bind(_assertThisInitialized(_this));
    _this.onInsertValue = _this.onInsertValue.bind(_assertThisInitialized(_this));
    _this.onDesc = _this.onDesc.bind(_assertThisInitialized(_this));
    _this.onTextDesc = _this.onTextDesc.bind(_assertThisInitialized(_this));
    _this.state = {
      value: _this.props.textareaValue,
      tabs: _this.props.tabs,
      tabsJSON: JSON.stringify(_this.props.tabs),
      activeKey: _this.props.activeKey,
      DocumentTreeData: _this.props.DocumentTreeData,
      DocumentTreeDataJSON: JSON.stringify(_this.props.DocumentTreeData),
      textDescription: '',
      id: '' // this.yyFormulasTextareaRef = React.createRef()

    };
    return _this;
  }

  _createClass(Formulas, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (nextProps.textareaValue != this.state.value) {
        this.setState({
          value: nextProps.textareaValue
        });
      }

      if (JSON.stringify(nextProps.tabs) != this.state.tabsJSON) {
        this.setState({
          tabs: nextProps.tabs,
          tabsJSON: JSON.stringify(nextProps.tabs)
        });
      }

      if (nextProps.activeKey != this.state.activeKey) {
        var activeKey = nextProps.activeKey;
        this.setState({
          activeKey: activeKey
        });
      }

      if (JSON.stringify(nextProps.DocumentTreeData) != this.state.DocumentTreeData) {
        this.setState({
          DocumentTreeData: nextProps.DocumentTreeData,
          DocumentTreeDataJSON: JSON.stringify(nextProps.DocumentTreeData)
        });
      }
    }
  }, {
    key: "onChange",
    value: function onChange(event) {
      var _this2 = this;

      var value = event.target.value;
      this.setState({
        value: value
      }, function () {
        _this2.props.onChange(value);
      });
    }
  }, {
    key: "onClick",
    value: function onClick(item) {
      if (this[item.event]) {
        this[item.event]();
      } else if (this.props[item.event]) {
        this.props[item.event](this.state.value);
      }
    }
  }, {
    key: "onCancel",
    value: function onCancel() {
      this.props.onCancel(this.state.value);
      this.setState({
        id: Math.random()
      });
    }
  }, {
    key: "onSubmit",
    value: function onSubmit() {
      this.props.onSubmit(this.state.value);
      this.setState({
        id: Math.random()
      });
    }
  }, {
    key: "onValidate",
    value: function onValidate() {
      this.props.onValidate(this.state.value);
    }
  }, {
    key: "onValueSelected",
    value: function onValueSelected() {
      // this.yyFormulasTextareaRef.current.select()
      this.yyFormulasTextareaRef.select();
    }
  }, {
    key: "onClear",
    value: function onClear() {
      var _this3 = this;

      this.setState({
        value: ''
      }, function () {
        _this3.props.onChange('');
      });
    }
  }, {
    key: "onInsertValue",
    value: function onInsertValue(val) {
      var _this4 = this;

      // console.log([this,this.yyFormulasTextareaRef])
      var yyFormulasTextareaRef = this.yyFormulasTextareaRef; // this.yyFormulasTextareaRef.current

      if (document.selection) {
        var sel = document.selection.createRange();
        sel.text = val;
      } else if (typeof yyFormulasTextareaRef.selectionStart === 'number' && typeof yyFormulasTextareaRef.selectionEnd === 'number') {
        var startPos = yyFormulasTextareaRef.selectionStart;
        var endPos = yyFormulasTextareaRef.selectionEnd;
        var tmpStr = this.state.value;
        var value = tmpStr.substring(0, startPos) + val + tmpStr.substring(endPos, tmpStr.length);
        this.setState({
          value: value
        }, function () {
          yyFormulasTextareaRef.selectionStart = _this4.state.value.length;
          yyFormulasTextareaRef.selectionEnd = _this4.state.value.length;
        });
      } else {
        this.setState({
          value: val
        }, function () {
          yyFormulasTextareaRef.selectionStart = _this4.state.value.length;
          yyFormulasTextareaRef.selectionEnd = _this4.state.value.length;
        });
      }
    }
  }, {
    key: "onDesc",
    value: function onDesc(key) {
      var textDescription = key ? key.toUpperCase() + '：' + this.props.Description['' + key.toUpperCase()] : '';
      this.setState({
        textDescription: textDescription
      });
    }
  }, {
    key: "onTextDesc",
    value: function onTextDesc(textDescription) {
      this.setState({
        textDescription: textDescription
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this5 = this;

      var _this$props = this.props,
          prefixCls = _this$props.prefixCls,
          textareaPlaceholder = _this$props.textareaPlaceholder,
          buttonList = _this$props.buttonList,
          tabsPrefixCls = _this$props.tabsPrefixCls,
          ReferDataUrl = _this$props.ReferDataUrl,
          fixedData = _this$props.fixedData,
          SubjectData = _this$props.SubjectData,
          FunctionData = _this$props.FunctionData,
          Description = _this$props.Description;
      return React.createElement("div", {
        className: prefixCls
      }, React.createElement("div", {
        className: "row"
      }, React.createElement("div", {
        className: prefixCls + '-textarea-warp col-xs-10 col-md-10 col-sm-10'
      }, React.createElement("textarea", {
        className: prefixCls + '-textarea form-control',
        onChange: this.onChange,
        placeholder: textareaPlaceholder,
        ref: function ref(_ref) {
          return _this5.yyFormulasTextareaRef = _ref;
        },
        value: this.state.value
      })), React.createElement("div", {
        className: prefixCls + '-button-warp col-xs-2 col-md-2 col-sm-2'
      }, buttonList.map(function (item, index) {
        return React.createElement("button", {
          key: index,
          className: prefixCls + '-button ' + item.className,
          onClick: _this5.onClick.bind(_this5, item)
        }, item.name);
      }))), React.createElement("div", {
        className: "row"
      }, React.createElement(TabsComponents, {
        prefixCls: tabsPrefixCls,
        tabs: this.state.tabs,
        activeKey: this.state.activeKey,
        DocumentTreeData: this.state.DocumentTreeData,
        onInsertValue: this.onInsertValue,
        ReferDataUrl: ReferDataUrl,
        fixedData: fixedData,
        SubjectData: SubjectData,
        onDesc: this.onDesc,
        onTextDesc: this.onTextDesc,
        FunctionData: FunctionData,
        Description: Description,
        onClear: this.onClear,
        id: this.state.id
      })), React.createElement("p", {
        className: "formulas-desc"
      }, this.state.textDescription));
    }
  }]);

  return Formulas;
}(React.Component);

var noop = function noop() {
  return null;
};

Formulas.propTypes = {
  prefixCls: PropTypes.string,
  textareaPlaceholder: PropTypes.string,
  textareaValue: PropTypes.string,
  buttonList: PropTypes.array,
  onCancel: PropTypes.func,
  onChange: PropTypes.func,
  onSubmit: PropTypes.func,
  onValidate: PropTypes.func,
  tabsPrefixCls: PropTypes.string,
  tabs: PropTypes.array,
  activeKey: PropTypes.string,
  //PropTypes.oneOfType([PropTypes.string,PropTypes.number]),
  DocumentTreeData: PropTypes.array,
  ReferDataUrl: PropTypes.string,
  fixedData: PropTypes.object,
  Description: PropTypes.object,
  FunctionData: PropTypes.array
};
Formulas.defaultProps = {
  prefixCls: 'yy-formulas',
  textareaPlaceholder: '请输入...',
  textareaValue: '',
  buttonList: [{
    name: '确定',
    className: 'btn btn-default',
    event: 'onSubmit'
  }, {
    name: '取消',
    className: 'btn btn-default',
    event: 'onCancel'
  }, {
    name: '验证',
    className: 'btn btn-default',
    event: 'onValidate'
  }, {
    name: '全选',
    className: 'btn btn-default',
    event: 'onValueSelected'
  }, {
    name: '清空',
    className: 'btn btn-default',
    event: 'onClear'
  }],
  onCancel: noop,
  onChange: noop,
  onSubmit: noop,
  onValidate: noop,
  tabsPrefixCls: 'rc-tabs',
  tabs: [{
    id: 0,
    name: '单据字段',
    type: 'sys',
    component: 'Document',
    disabled: false,
    placeholder: '请输入...',
    notFoundContent: '暂无数据',
    positionName: '定位:',
    okName: '确定'
  }, {
    id: 1,
    name: '固定值',
    type: 'sys',
    component: 'Fixed',
    disabled: false,
    placeholder: '请输入...',
    notFoundContent: '暂无数据',
    showName1: '档案',
    showName2: '档案值'
  }, {
    id: 2,
    name: '科目对照',
    type: 'sys',
    component: 'Subject',
    disabled: false,
    placeholder: '请输入...',
    notFoundContent: '暂无数据',
    positionName: '定位：',
    okName: '确定',
    okName2: '插入'
  }, {
    id: 3,
    name: '辅助核算类型',
    type: 'sys',
    component: 'Auxiliary',
    disabled: false,
    placeholder: '请输入...',
    notFoundContent: '暂无数据',
    showName: '辅助核算类型',
    onChange: noop
  }, {
    id: 4,
    name: '辅助核算值',
    type: 'sys',
    component: 'Auxiliary',
    disabled: false,
    placeholder: '请输入...',
    notFoundContent: '暂无数据',
    showName: '辅助核算值'
  }, {
    id: 5,
    name: '函数',
    type: 'sys',
    component: 'Function',
    disabled: false,
    notFoundContent: '暂无数据',
    positionName: '定位:',
    okName: '确定'
  }],
  activeKey: '0',
  DocumentTreeData: [],
  ReferDataUrl: '',
  fixedData: {},
  Description: {},
  FunctionData: []
};
polyfill(Formulas);
export default Formulas;
